@@ -4,6 +4,10 @@
 # Copyright (c) 2022 Ingram Micro. All Rights Reserved.
 #
 
+"""
+Module messages definition file
+"""
+
 PARAMETER_NOT_FOUND = ('The required parameter "{param_id}" is not configured. '
                        'Please, set up this parameter to continue with the request.')
 
